@@ -1,6 +1,7 @@
 "f2flo" <-
-function(f, pp=NA) {
+function(f, pp=NA, xlo=NULL) {
    if(! check.fs(f)) return(FALSE)
+   if(! is.null(xlo)) pp <- xlo$pp
    if(is.na(pp)) {
       warning("pp can not be NA")
       return(FALSE)
@@ -10,6 +11,7 @@ function(f, pp=NA) {
         return(FALSE)
       }
    }
+   f  <- f[f >= pp]
    zs <- (f-pp)/(1-pp)
    if(any(zs < 0) || any(zs > 1)) {
       warning("invalid nonexceedance probability after pp conditioning")
