@@ -10,9 +10,7 @@ function(x,para) {
         f <- A^(-1) * exp(-Y)
     } else {
         ARG <- 1-K*Y
-        ops <- options(warn = -1)
-        Y <- -log(ARG)/K
-        options(ops)
+        Y <- suppressWarnings( -log(ARG)/K )
         f <- A^(-1) * exp(-(1-K)*Y)
     }
 
